package au.com.infomedix.notransaction;

import java.util.Enumeration;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

import javax.jcr.Node;
import javax.jcr.Repository;
import javax.jcr.Session;

import org.apache.log4j.Appender;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Layout;
import org.apache.log4j.Level;
import org.apache.log4j.LogManager;
import org.apache.log4j.PatternLayout;
import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.modeshape.jcr.ModeShapeEngine;
import org.modeshape.jcr.RepositoryConfiguration;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class TransactionTest {
    private static Logger log = LoggerFactory.getLogger(TransactionTest.class);

    private Repository repository;

    private ModeShapeEngine engine;

    @BeforeClass
    public static void classInit()
    {
        BasicConfigurator.configure();
        LogManager.getRootLogger().setLevel((Level) Level.INFO);

        Enumeration apps   = LogManager.getRootLogger().getAllAppenders();
        Layout      layout = new PatternLayout("%d{ABSOLUTE} %5p %c{1}:%L - %m%n");

        // there should only be the one appender...
        while(apps.hasMoreElements())
        {
            ((Appender) apps.nextElement()).setLayout(layout);
        }
    }

    @Before
    public void init()
              throws Exception
    {
        RepositoryConfiguration config = RepositoryConfiguration.read("SimpleDataRepository.json");
        engine = new ModeShapeEngine();
        engine.start();
        engine.deploy(config);

        repository = (Repository) engine.getRepository("DataRepository");
    }

    @After
    public void unInit()
                throws Exception
    {
        Future<Boolean> result = engine.shutdown(true);
        result.get(10, TimeUnit.SECONDS);
    }

    @Test
    public void simpleAccess() throws Exception
    {
        Session session = null;

        try
        {
            session = repository.login();

            log.info("Add testRoot node");

            Node testRoot = session.getRootNode().addNode("testRoot", "nt:folder");
            
            log.info("Save Session");
            session.save();
            log.info("Saved Session");
        }
        finally
        {
            if(session != null)
            {
                session.logout();
            }
        }

    }
}
